var group__pw__session__manager =
[
    [ "session-manager.h", "session-manager_8h.html", null ],
    [ "impl-interfaces.h", "impl-interfaces_8h.html", null ],
    [ "interfaces.h", "interfaces_8h.html", null ],
    [ "introspect.h", "introspect_8h.html", null ],
    [ "introspect-funcs.h", "introspect-funcs_8h.html", null ],
    [ "keys.h", "src_2pipewire_2extensions_2session-manager_2keys_8h.html", null ],
    [ "pw_client_endpoint_events", "structpw__client__endpoint__events.html", [
      [ "version", "structpw__client__endpoint__events.html#afab781a09b218afdc2c9ffb54502be5e", null ],
      [ "set_session_id", "structpw__client__endpoint__events.html#a12f427748eebbfd39cdc4f75a9db57ed", null ],
      [ "set_param", "structpw__client__endpoint__events.html#a45e7bb70eb2b24c33aad0c82dcf001b6", null ],
      [ "stream_set_param", "structpw__client__endpoint__events.html#a43e06e14ba4461922bfce4c3c98c13f1", null ],
      [ "create_link", "structpw__client__endpoint__events.html#a02d8f4d9cd9f898d3109a64f7afd81e1", null ]
    ] ],
    [ "pw_client_endpoint_methods", "structpw__client__endpoint__methods.html", [
      [ "version", "structpw__client__endpoint__methods.html#a58fe2e1f1524cf0f22dda84f7f9c33e0", null ],
      [ "add_listener", "structpw__client__endpoint__methods.html#a283f6ec14d1a3ff9b0b0aa213b2ea850", null ],
      [ "update", "group__pw__session__manager.html#gaa8366fa5903ce48d728d5a4bf1eb6ff2", null ],
      [ "stream_update", "group__pw__session__manager.html#gaf6d9b5f36fb09c37ae8e1cd3716618e5", null ]
    ] ],
    [ "pw_client_session_events", "structpw__client__session__events.html", [
      [ "version", "structpw__client__session__events.html#a6005c505de498fbaaaed2dd87918773f", null ],
      [ "set_param", "structpw__client__session__events.html#a8e823bcde1844c0857314b10069f3b8d", null ],
      [ "link_set_param", "structpw__client__session__events.html#af3eab807465363845550f89f1bb9d816", null ],
      [ "link_request_state", "structpw__client__session__events.html#aae0dc344c9b1d62b21fb16e4fc2c9c33", null ]
    ] ],
    [ "pw_client_session_methods", "structpw__client__session__methods.html", [
      [ "version", "structpw__client__session__methods.html#a4537bb47cfe11b27649ffe082fdd49fa", null ],
      [ "add_listener", "structpw__client__session__methods.html#a54ba399f450c8ee5b85cfba7ad4b352a", null ],
      [ "update", "group__pw__session__manager.html#gab104098c9fd6fad4bbe290509aefbe20", null ],
      [ "link_update", "group__pw__session__manager.html#gad11c6d8d430ddbe887f200ea7b4c33d1", null ]
    ] ],
    [ "pw_session_events", "structpw__session__events.html", [
      [ "version", "structpw__session__events.html#a9156a82a54dba4f5e6f7b045a31b5ac7", null ],
      [ "info", "structpw__session__events.html#a36371c5decff93c9c0c0688c19b2780c", null ],
      [ "param", "structpw__session__events.html#a6d9e402e306432f33e6fe085599416d7", null ]
    ] ],
    [ "pw_session_methods", "structpw__session__methods.html", [
      [ "version", "structpw__session__methods.html#a39a82c063c97d967e5ee82589c390c29", null ],
      [ "add_listener", "structpw__session__methods.html#afeb231bfac6c5539d258eb06b22e0acf", null ],
      [ "subscribe_params", "structpw__session__methods.html#a6720d4c6b23022393bc945c656ba5fe0", null ],
      [ "enum_params", "structpw__session__methods.html#a9311ff4c5e45bce0b1a56ee64e720b09", null ],
      [ "set_param", "structpw__session__methods.html#a66e604601841f9f2252db7c4a4466f6f", null ]
    ] ],
    [ "pw_endpoint_events", "structpw__endpoint__events.html", [
      [ "version", "structpw__endpoint__events.html#ac01eef7eb942d89fb0437ee91df13522", null ],
      [ "info", "structpw__endpoint__events.html#a80267d5ed443bb1b924b8bbe89375c5f", null ],
      [ "param", "structpw__endpoint__events.html#a89bfc5609cf692b853de5d46da2dbc01", null ]
    ] ],
    [ "pw_endpoint_methods", "structpw__endpoint__methods.html", [
      [ "version", "structpw__endpoint__methods.html#a06713ce8a9d182272a9552da9d0c229f", null ],
      [ "add_listener", "structpw__endpoint__methods.html#a57ed4ba10caacf4575e7a7644d17f5e2", null ],
      [ "subscribe_params", "structpw__endpoint__methods.html#a6bc6ff48ccd0c3c56d24c00017c9a20b", null ],
      [ "enum_params", "structpw__endpoint__methods.html#af6edf84d00162a4ad7a25d417be5358b", null ],
      [ "set_param", "structpw__endpoint__methods.html#ab78e5de3c1ca35dfcb09881d58f46ba2", null ],
      [ "create_link", "structpw__endpoint__methods.html#a981eeb169f40ac34ad5c348572a3eb95", null ]
    ] ],
    [ "pw_endpoint_stream_events", "structpw__endpoint__stream__events.html", [
      [ "version", "structpw__endpoint__stream__events.html#a2deefdff752b1d55ef2d85821b09b04a", null ],
      [ "info", "structpw__endpoint__stream__events.html#ab37cc600d299d1d394d825d151d640c5", null ],
      [ "param", "structpw__endpoint__stream__events.html#aaf1e568a1ebca79113dca8de94c6763a", null ]
    ] ],
    [ "pw_endpoint_stream_methods", "structpw__endpoint__stream__methods.html", [
      [ "version", "structpw__endpoint__stream__methods.html#ab73e2f70fc5a78721ebb38118af947b5", null ],
      [ "add_listener", "structpw__endpoint__stream__methods.html#a06d4d4c207f88dd3e87dadee7401b785", null ],
      [ "subscribe_params", "structpw__endpoint__stream__methods.html#ae9591b91164d11c342bfb44f87010932", null ],
      [ "enum_params", "structpw__endpoint__stream__methods.html#ab7b9c94de60336876dac12fbd671e8cb", null ],
      [ "set_param", "structpw__endpoint__stream__methods.html#a795f1ab22b0899bc18142419723e369b", null ]
    ] ],
    [ "pw_endpoint_link_events", "structpw__endpoint__link__events.html", [
      [ "version", "structpw__endpoint__link__events.html#ac94440a980f13b2ec1dca2be768d7a2e", null ],
      [ "info", "structpw__endpoint__link__events.html#ac358bf9f098e9a01690fb72901927427", null ],
      [ "param", "structpw__endpoint__link__events.html#ade3caa4760973bd219b5b8845a2ab8f6", null ]
    ] ],
    [ "pw_endpoint_link_methods", "structpw__endpoint__link__methods.html", [
      [ "version", "structpw__endpoint__link__methods.html#a339f0750fb1ab4709b832f87366a0f60", null ],
      [ "add_listener", "structpw__endpoint__link__methods.html#a790b919611ad52e740c6c3baa09f2bf0", null ],
      [ "subscribe_params", "structpw__endpoint__link__methods.html#ac85085528468519f49c7bba87a12f2cd", null ],
      [ "enum_params", "structpw__endpoint__link__methods.html#acb694bb5ac728b0b436b71815732b9e2", null ],
      [ "set_param", "structpw__endpoint__link__methods.html#a000fb2581dc5831e616635aca029165e", null ],
      [ "request_state", "structpw__endpoint__link__methods.html#a2e15950aee91de65432410de0889a91f", null ]
    ] ],
    [ "pw_session_info", "structpw__session__info.html", [
      [ "version", "structpw__session__info.html#aa58e4f042f5cf3226d0765654439a9a3", null ],
      [ "id", "structpw__session__info.html#aa2d06aa8a36c3da1890e37f02e4702a6", null ],
      [ "change_mask", "structpw__session__info.html#a1289ec21ec9441f29314a561b341cf13", null ],
      [ "params", "structpw__session__info.html#a00aaf0720fd58ae285a1fe122ab0fb93", null ],
      [ "n_params", "structpw__session__info.html#abfebf0a6ad9331c4690ffad37894d660", null ]
    ] ],
    [ "pw_endpoint_info", "structpw__endpoint__info.html", [
      [ "version", "structpw__endpoint__info.html#abbedd652482907400c17a0e19ed4eefd", null ],
      [ "id", "structpw__endpoint__info.html#a444b5b544b0d120912b38a19c04da4f5", null ],
      [ "media_class", "structpw__endpoint__info.html#ac9c79172b3c9d4a42d622896d357eb4a", null ],
      [ "direction", "structpw__endpoint__info.html#a53e7835959ec347ff84295673cf8e834", null ],
      [ "flags", "structpw__endpoint__info.html#a652272ff97cabdbc2cb630e631319894", null ],
      [ "change_mask", "structpw__endpoint__info.html#a50f24fd870f36fe554ff1ce0cf29ab92", null ],
      [ "n_streams", "structpw__endpoint__info.html#af238696ba49e512e921eea434d3dee54", null ],
      [ "session_id", "structpw__endpoint__info.html#add8888495992bb7b239f5538db21202f", null ],
      [ "params", "structpw__endpoint__info.html#a1b2b450d001a613908596afb785c9bf6", null ],
      [ "n_params", "structpw__endpoint__info.html#a6509522ee4d9d9d6c2c546938b24f5bc", null ]
    ] ],
    [ "pw_endpoint_stream_info", "structpw__endpoint__stream__info.html", [
      [ "version", "structpw__endpoint__stream__info.html#ae5c7fb592c52111ce8bfc96faf4fb523", null ],
      [ "id", "structpw__endpoint__stream__info.html#ae2e6491fda9eacf17fb4bf05caf5fe06", null ],
      [ "endpoint_id", "structpw__endpoint__stream__info.html#a24e5e8c23830fcf15bca4513230b6bf8", null ],
      [ "change_mask", "structpw__endpoint__stream__info.html#ae7e20969d89c3c94e3f073a5e433a80b", null ],
      [ "link_params", "structpw__endpoint__stream__info.html#ae1e52d894dfd26fac731016958df44cc", null ],
      [ "params", "structpw__endpoint__stream__info.html#a1edec61e343d4e5a7433258765704c9b", null ],
      [ "n_params", "structpw__endpoint__stream__info.html#a083c2b84553da989d2dfde58cf8fcb50", null ]
    ] ],
    [ "pw_endpoint_link_info", "structpw__endpoint__link__info.html", [
      [ "version", "structpw__endpoint__link__info.html#aaae0e9204b82b599f01bfcafe7573103", null ],
      [ "id", "structpw__endpoint__link__info.html#a07c6bf548b8e042c2812543981a51598", null ],
      [ "session_id", "structpw__endpoint__link__info.html#af223a0fa8116ac65191724bd0feb0a74", null ],
      [ "output_endpoint_id", "structpw__endpoint__link__info.html#a1d398555b2824d65fda91cfd3258a813", null ],
      [ "output_stream_id", "structpw__endpoint__link__info.html#aea0b70e668d2c6c0dbec40bfc6b6ff62", null ],
      [ "input_endpoint_id", "structpw__endpoint__link__info.html#a460974a8c40082a75b90d5d151e93ca7", null ],
      [ "input_stream_id", "structpw__endpoint__link__info.html#aea87c1744850124ef9bc31d92af578f1", null ],
      [ "change_mask", "structpw__endpoint__link__info.html#a0c23a32dc6e567f7cf483a20c988feb3", null ],
      [ "state", "structpw__endpoint__link__info.html#abe1a77c360812808ac34d2ab016f6bd7", null ],
      [ "error", "structpw__endpoint__link__info.html#a7effc16feab6bfc6322e96d90ebea27d", null ],
      [ "params", "structpw__endpoint__link__info.html#abbca6b1e2d0509bea65aff817962e0e7", null ],
      [ "n_params", "structpw__endpoint__link__info.html#ae0c6caf742470e3133cd0de7a7e642a9", null ]
    ] ],
    [ "pw_client_endpoint", "structpw__client__endpoint.html", null ],
    [ "pw_client_session", "structpw__client__session.html", null ],
    [ "pw_session", "structpw__session.html", null ],
    [ "pw_endpoint", "structpw__endpoint.html", null ],
    [ "pw_endpoint_stream", "structpw__endpoint__stream.html", null ],
    [ "pw_endpoint_link", "structpw__endpoint__link.html", null ],
    [ "PW_TYPE_INTERFACE_ClientEndpoint", "group__pw__session__manager.html#gaba0b7ddf015d127286c0afa1df92e68b", null ],
    [ "PW_VERSION_CLIENT_ENDPOINT", "group__pw__session__manager.html#gacd6f7d3bf11036b1ab8ca0fe7950b611", null ],
    [ "PW_CLIENT_ENDPOINT_EVENT_SET_SESSION_ID", "group__pw__session__manager.html#ga10c31c04d8ed4a8f4670a35af75e8caa", null ],
    [ "PW_CLIENT_ENDPOINT_EVENT_SET_PARAM", "group__pw__session__manager.html#ga68e9035f497ceed218c7ab0a141706a2", null ],
    [ "PW_CLIENT_ENDPOINT_EVENT_STREAM_SET_PARAM", "group__pw__session__manager.html#gacbd7547af9c62d9770c940425e7ff74c", null ],
    [ "PW_CLIENT_ENDPOINT_EVENT_CREATE_LINK", "group__pw__session__manager.html#ga8cc3508fc23136d756dafc0c6142d299", null ],
    [ "PW_CLIENT_ENDPOINT_EVENT_NUM", "group__pw__session__manager.html#gacfc215ae22e6a99a5ff459f928d24daa", null ],
    [ "PW_VERSION_CLIENT_ENDPOINT_EVENTS", "group__pw__session__manager.html#ga4df76fed32552db3121ff82716cd161c", null ],
    [ "PW_CLIENT_ENDPOINT_METHOD_ADD_LISTENER", "group__pw__session__manager.html#ga9c189d1f82467baaf78c4863c8320b3c", null ],
    [ "PW_CLIENT_ENDPOINT_METHOD_UPDATE", "group__pw__session__manager.html#ga14a1a62d523f118d17acb9bc67bd29eb", null ],
    [ "PW_CLIENT_ENDPOINT_METHOD_STREAM_UPDATE", "group__pw__session__manager.html#ga1c21ac4fad8f103846eb54b77422c6b1", null ],
    [ "PW_CLIENT_ENDPOINT_METHOD_NUM", "group__pw__session__manager.html#gaf2cef524c89f69a149ae8e9017dd1d59", null ],
    [ "PW_VERSION_CLIENT_ENDPOINT_METHODS", "group__pw__session__manager.html#gabbe5787b3c981d049652423e44dd75f1", null ],
    [ "pw_client_endpoint_method", "group__pw__session__manager.html#gaf970d7b3860e6042cd522ccd012bc6d9", null ],
    [ "pw_client_endpoint_add_listener", "group__pw__session__manager.html#ga9ea9d15f9c2b54a69cd4b27f5f300b99", null ],
    [ "pw_client_endpoint_update", "group__pw__session__manager.html#gac6de4f724864d879d897a397074775c4", null ],
    [ "pw_client_endpoint_stream_update", "group__pw__session__manager.html#gaa50cf4a5a59e55e6a003e21cc6376996", null ],
    [ "PW_TYPE_INTERFACE_ClientSession", "group__pw__session__manager.html#ga50daa56e8d31fa03e61ea748d4d2e31a", null ],
    [ "PW_VERSION_CLIENT_SESSION", "group__pw__session__manager.html#ga6772def682a60b837c3234aa81e53c04", null ],
    [ "PW_CLIENT_SESSION_EVENT_SET_PARAM", "group__pw__session__manager.html#gadd2aee4a3448612433ba7afd106f958e", null ],
    [ "PW_CLIENT_SESSION_EVENT_LINK_SET_PARAM", "group__pw__session__manager.html#ga640eb23a56a0f38002b3f7d4ce5ce501", null ],
    [ "PW_CLIENT_SESSION_EVENT_LINK_REQUEST_STATE", "group__pw__session__manager.html#ga881a2318b6234ad0869472a22141a906", null ],
    [ "PW_CLIENT_SESSION_EVENT_NUM", "group__pw__session__manager.html#gae37385808f4158bcf174ed7ca351f1f8", null ],
    [ "PW_VERSION_CLIENT_SESSION_EVENTS", "group__pw__session__manager.html#ga061b1a63dcbc70226273140b6191b19c", null ],
    [ "PW_CLIENT_SESSION_METHOD_ADD_LISTENER", "group__pw__session__manager.html#gab9f710e43a7bf7097f7de9064e8d677c", null ],
    [ "PW_CLIENT_SESSION_METHOD_UPDATE", "group__pw__session__manager.html#ga8a2eaf7340c0b68ce278dd14d4cccbed", null ],
    [ "PW_CLIENT_SESSION_METHOD_LINK_UPDATE", "group__pw__session__manager.html#gad24f77119775ca68f779962e9e7f5db9", null ],
    [ "PW_CLIENT_SESSION_METHOD_NUM", "group__pw__session__manager.html#gafb50cde478463be9002e3fee8eec2446", null ],
    [ "PW_VERSION_CLIENT_SESSION_METHODS", "group__pw__session__manager.html#gad3c376ad030aaebfd69c6d242c5744a3", null ],
    [ "pw_client_session_method", "group__pw__session__manager.html#ga6610bf9f3b9504539dfe55bd50588708", null ],
    [ "pw_client_session_add_listener", "group__pw__session__manager.html#gaa901c089ae02f35b58d4368f99d94b26", null ],
    [ "pw_client_session_update", "group__pw__session__manager.html#ga1df3e3242c1438fe35c454dd3ed41219", null ],
    [ "pw_client_session_link_update", "group__pw__session__manager.html#ga8b55930c438fa7f090ca2b03a9709c18", null ],
    [ "PW_TYPE_INTERFACE_Session", "group__pw__session__manager.html#gae9cbccb8f8ecae1b281d29d538d0f6f0", null ],
    [ "PW_SESSION_PERM_MASK", "group__pw__session__manager.html#gaed0cfc07ccdb5a3e8c1578c9216279be", null ],
    [ "PW_VERSION_SESSION", "group__pw__session__manager.html#ga61c63491758436617fc59af4f263b4eb", null ],
    [ "PW_TYPE_INTERFACE_Endpoint", "group__pw__session__manager.html#gaa7bf956682a13c8dabda82c6c388b7e9", null ],
    [ "PW_ENDPOINT_PERM_MASK", "group__pw__session__manager.html#gab9526991696ac2886e4d266c22d40594", null ],
    [ "PW_VERSION_ENDPOINT", "group__pw__session__manager.html#ga3126b0d16a1105a0075ffdc1b8d25fc4", null ],
    [ "PW_TYPE_INTERFACE_EndpointStream", "group__pw__session__manager.html#ga5bc56193f4eaa23ab2e494aab49249a7", null ],
    [ "PW_ENDPOINT_STREAM_PERM_MASK", "group__pw__session__manager.html#gaeafaf4dbb69984ba067ad380debee99e", null ],
    [ "PW_VERSION_ENDPOINT_STREAM", "group__pw__session__manager.html#gaee511508513a161959dbc4e30b682dff", null ],
    [ "PW_TYPE_INTERFACE_EndpointLink", "group__pw__session__manager.html#ga93d8f2ddcda53c926ecc085fede31446", null ],
    [ "PW_ENDPOINT_LINK_PERM_MASK", "group__pw__session__manager.html#gaa9d5f9aa179c065024484e0e1674d3a1", null ],
    [ "PW_VERSION_ENDPOINT_LINK", "group__pw__session__manager.html#gac90ad5edf844a20a969b19c48c2f1d18", null ],
    [ "PW_SESSION_EVENT_INFO", "group__pw__session__manager.html#ga7e51bfdb707f25b2222dfae9c6dc7dea", null ],
    [ "PW_SESSION_EVENT_PARAM", "group__pw__session__manager.html#ga66409c7725bcc8631015483d84f731c9", null ],
    [ "PW_SESSION_EVENT_NUM", "group__pw__session__manager.html#ga4d58993497b9b9b1cca7802ef1f813ab", null ],
    [ "PW_VERSION_SESSION_EVENTS", "group__pw__session__manager.html#ga703c828d651cc8fdb939db06468c6956", null ],
    [ "PW_SESSION_METHOD_ADD_LISTENER", "group__pw__session__manager.html#ga6068d234f2810c9c5eb64be9e1eb3b23", null ],
    [ "PW_SESSION_METHOD_SUBSCRIBE_PARAMS", "group__pw__session__manager.html#gae6f7a22ae1e3af0455eed4ffa02df2bf", null ],
    [ "PW_SESSION_METHOD_ENUM_PARAMS", "group__pw__session__manager.html#ga9f380188172b465eb8178eace5aaf02b", null ],
    [ "PW_SESSION_METHOD_SET_PARAM", "group__pw__session__manager.html#gadc7336cdf4895ca1cedee1582bf35d53", null ],
    [ "PW_SESSION_METHOD_CREATE_LINK", "group__pw__session__manager.html#ga0a0e349bd0024457457e6f56dc0fbeb3", null ],
    [ "PW_SESSION_METHOD_NUM", "group__pw__session__manager.html#ga0a2fbf1e9c6493db2e61e629647dda82", null ],
    [ "PW_VERSION_SESSION_METHODS", "group__pw__session__manager.html#ga7d86a53322280ecfcc47734de89449fe", null ],
    [ "pw_session_method", "group__pw__session__manager.html#gaac78e333b32802852a748a59122c31b1", null ],
    [ "pw_session_add_listener", "group__pw__session__manager.html#gae8e691fd4d6dadf9683d2f377346d1bb", null ],
    [ "pw_session_subscribe_params", "group__pw__session__manager.html#ga597ff60eeb75dd0f833f604b51ac5368", null ],
    [ "pw_session_enum_params", "group__pw__session__manager.html#gaf0eda2a9d871c4d9eeaf187771eb58cb", null ],
    [ "pw_session_set_param", "group__pw__session__manager.html#gaa01cdd7877f44f5e3cea92a8e22480ab", null ],
    [ "PW_ENDPOINT_EVENT_INFO", "group__pw__session__manager.html#ga3e540bd1f6f3ba78a5642862792be5c0", null ],
    [ "PW_ENDPOINT_EVENT_PARAM", "group__pw__session__manager.html#gaa402cd6473e92b77d7f66d42dba6720f", null ],
    [ "PW_ENDPOINT_EVENT_NUM", "group__pw__session__manager.html#gab62fb0a5129ee8d80c2f898aaa48b6ff", null ],
    [ "PW_VERSION_ENDPOINT_EVENTS", "group__pw__session__manager.html#gabe87899411253a47fc22cda8b6d60524", null ],
    [ "PW_ENDPOINT_METHOD_ADD_LISTENER", "group__pw__session__manager.html#ga2e7a34daf8b8253ed9bffd78cdca8e7f", null ],
    [ "PW_ENDPOINT_METHOD_SUBSCRIBE_PARAMS", "group__pw__session__manager.html#ga00906166f757acda0920e5e94e7a0002", null ],
    [ "PW_ENDPOINT_METHOD_ENUM_PARAMS", "group__pw__session__manager.html#gab48a226b48e006093ea7849eada7a806", null ],
    [ "PW_ENDPOINT_METHOD_SET_PARAM", "group__pw__session__manager.html#gad3384aa12086bbb66d84355d49a2b537", null ],
    [ "PW_ENDPOINT_METHOD_CREATE_LINK", "group__pw__session__manager.html#ga2de263210f215bfe195aa672b33168d3", null ],
    [ "PW_ENDPOINT_METHOD_NUM", "group__pw__session__manager.html#ga013bd15be1036877f208d4ae5adf3efa", null ],
    [ "PW_VERSION_ENDPOINT_METHODS", "group__pw__session__manager.html#ga593348bb9caa0787b94469fc45862543", null ],
    [ "pw_endpoint_method", "group__pw__session__manager.html#ga750ac9ec4fbc497f95536c95f4561ee6", null ],
    [ "pw_endpoint_add_listener", "group__pw__session__manager.html#gafaab3e85d45911fd9f1fcfb5a106470c", null ],
    [ "pw_endpoint_subscribe_params", "group__pw__session__manager.html#gac5e4513214ca0ca5a35931593b3ad84c", null ],
    [ "pw_endpoint_enum_params", "group__pw__session__manager.html#ga13d05f9dfe68e845ef1ffb1fc2cb8565", null ],
    [ "pw_endpoint_set_param", "group__pw__session__manager.html#ga6f46bdea51a973e31cada37277955aab", null ],
    [ "pw_endpoint_create_link", "group__pw__session__manager.html#ga659e95476b1273ad6b2d247256375df7", null ],
    [ "PW_ENDPOINT_STREAM_EVENT_INFO", "group__pw__session__manager.html#ga7bd339deb3e56304f3e0e84496d768ad", null ],
    [ "PW_ENDPOINT_STREAM_EVENT_PARAM", "group__pw__session__manager.html#gad1df6ce293f28e872e608f95fbad9c7c", null ],
    [ "PW_ENDPOINT_STREAM_EVENT_NUM", "group__pw__session__manager.html#gabe0075fd89732e5f50c189456cb9e7cd", null ],
    [ "PW_VERSION_ENDPOINT_STREAM_EVENTS", "group__pw__session__manager.html#ga2f3475c7169a333132c7adf5ab5f818b", null ],
    [ "PW_ENDPOINT_STREAM_METHOD_ADD_LISTENER", "group__pw__session__manager.html#gaa17ffb9525d1063cdff54c7dcc5cda2d", null ],
    [ "PW_ENDPOINT_STREAM_METHOD_SUBSCRIBE_PARAMS", "group__pw__session__manager.html#gabf6a98119e15ceadfe6a59113d7b02ed", null ],
    [ "PW_ENDPOINT_STREAM_METHOD_ENUM_PARAMS", "group__pw__session__manager.html#ga9607fbb274c946bef74157df3e059427", null ],
    [ "PW_ENDPOINT_STREAM_METHOD_SET_PARAM", "group__pw__session__manager.html#gadfe39f46f5b89a4931acee559a6be7bc", null ],
    [ "PW_ENDPOINT_STREAM_METHOD_NUM", "group__pw__session__manager.html#ga7942053dc37f4422c4342845b98013ca", null ],
    [ "PW_VERSION_ENDPOINT_STREAM_METHODS", "group__pw__session__manager.html#gabeb0d8c385ec6cf66f05197cd0c18de0", null ],
    [ "pw_endpoint_stream_method", "group__pw__session__manager.html#ga9e7a7a0f7a48b2f6afc5b34cd488695a", null ],
    [ "pw_endpoint_stream_add_listener", "group__pw__session__manager.html#gacbd33698583c94ce4007c936e4460e62", null ],
    [ "pw_endpoint_stream_subscribe_params", "group__pw__session__manager.html#ga748a0b2bb21288f7ad06e741598246a8", null ],
    [ "pw_endpoint_stream_enum_params", "group__pw__session__manager.html#ga4ff212cceeb7cd638388e0a62e590ec5", null ],
    [ "pw_endpoint_stream_set_param", "group__pw__session__manager.html#ga666c22d90558b5ce7aeaee71537fafd5", null ],
    [ "PW_ENDPOINT_LINK_EVENT_INFO", "group__pw__session__manager.html#ga6bac1a57bbfb7b6899ea70f9a49cbdd3", null ],
    [ "PW_ENDPOINT_LINK_EVENT_PARAM", "group__pw__session__manager.html#ga8d867100ede94c7d68d65942bc22feb6", null ],
    [ "PW_ENDPOINT_LINK_EVENT_NUM", "group__pw__session__manager.html#gad76fdb1a9cbee79f5e83dc4f3bcaf1ee", null ],
    [ "PW_VERSION_ENDPOINT_LINK_EVENTS", "group__pw__session__manager.html#ga36c9ea5feb170e0ed71922b1b5d92cc3", null ],
    [ "PW_ENDPOINT_LINK_METHOD_ADD_LISTENER", "group__pw__session__manager.html#ga771b101ee652676e0a596d74460a6354", null ],
    [ "PW_ENDPOINT_LINK_METHOD_SUBSCRIBE_PARAMS", "group__pw__session__manager.html#ga4d06e16fc6fef534823da1d2df92df7d", null ],
    [ "PW_ENDPOINT_LINK_METHOD_ENUM_PARAMS", "group__pw__session__manager.html#ga1069edd0047bbb473360862df48e2919", null ],
    [ "PW_ENDPOINT_LINK_METHOD_SET_PARAM", "group__pw__session__manager.html#ga8d624794eabaa58baa456896d6bff246", null ],
    [ "PW_ENDPOINT_LINK_METHOD_REQUEST_STATE", "group__pw__session__manager.html#ga46d1d57086e1b274ededf1e2a9e775fe", null ],
    [ "PW_ENDPOINT_LINK_METHOD_DESTROY", "group__pw__session__manager.html#ga50b12cda4e64ff65506445676d9e3569", null ],
    [ "PW_ENDPOINT_LINK_METHOD_NUM", "group__pw__session__manager.html#ga5f9b89c86a974aea7971c88fdc6b35b8", null ],
    [ "PW_VERSION_ENDPOINT_LINK_METHODS", "group__pw__session__manager.html#gaa6b4a8b98c7447bbd98d4735ba71feae", null ],
    [ "pw_endpoint_link_method", "group__pw__session__manager.html#ga4dbd4de9d111033fc7df3b08194a0e0e", null ],
    [ "pw_endpoint_link_add_listener", "group__pw__session__manager.html#ga6cdfee6570f07ce60d6ee3cc22e730c3", null ],
    [ "pw_endpoint_link_subscribe_params", "group__pw__session__manager.html#gaaa4097e754be1ef65c9cd385043ef35c", null ],
    [ "pw_endpoint_link_enum_params", "group__pw__session__manager.html#gacf65a96b2b6cb1f16af259bc667518bd", null ],
    [ "pw_endpoint_link_set_param", "group__pw__session__manager.html#ga9ce6b085d6110a166e03135e3977c7f2", null ],
    [ "pw_endpoint_link_request_state", "group__pw__session__manager.html#gada9db2cdf68ff40883ead59f0fd7d007", null ],
    [ "PW_VERSION_SESSION_INFO", "group__pw__session__manager.html#ga08be0f2d923af19e43e0a292d0bd351d", null ],
    [ "PW_SESSION_CHANGE_MASK_PROPS", "group__pw__session__manager.html#ga294e1f89f88e8c143a0fdc10f6b5c19f", null ],
    [ "PW_SESSION_CHANGE_MASK_PARAMS", "group__pw__session__manager.html#gaca1ae64643a150fbe2878067856b629a", null ],
    [ "PW_SESSION_CHANGE_MASK_ALL", "group__pw__session__manager.html#ga5dcc90ed21aba1329ab2f1c1279c18ad", null ],
    [ "PW_VERSION_ENDPOINT_INFO", "group__pw__session__manager.html#ga81bd4886f69e2d119c3fb59217bff171", null ],
    [ "PW_ENDPOINT_FLAG_PROVIDES_SESSION", "group__pw__session__manager.html#ga31cff50a1b1c9652e16d4666b39f890a", null ],
    [ "PW_ENDPOINT_CHANGE_MASK_STREAMS", "group__pw__session__manager.html#ga4e680de3fd590b1b9988791df5a57be9", null ],
    [ "PW_ENDPOINT_CHANGE_MASK_SESSION", "group__pw__session__manager.html#ga34caaf07827cde7ac74e35a2c23c4dde", null ],
    [ "PW_ENDPOINT_CHANGE_MASK_PROPS", "group__pw__session__manager.html#ga6c99759eac5533dee0959cb756cf988a", null ],
    [ "PW_ENDPOINT_CHANGE_MASK_PARAMS", "group__pw__session__manager.html#ga81fbab389aafd05f10740275c1bc573a", null ],
    [ "PW_ENDPOINT_CHANGE_MASK_ALL", "group__pw__session__manager.html#ga638a14bb21921dcaa09283a76a81f7a5", null ],
    [ "PW_VERSION_ENDPOINT_STREAM_INFO", "group__pw__session__manager.html#ga15ca6aed2bb2a0b703363df5566fe682", null ],
    [ "PW_ENDPOINT_STREAM_CHANGE_MASK_LINK_PARAMS", "group__pw__session__manager.html#gad8db2478f601797968df4130216adadf", null ],
    [ "PW_ENDPOINT_STREAM_CHANGE_MASK_PROPS", "group__pw__session__manager.html#ga3e4945a8ef7615d8e4b574209890a68b", null ],
    [ "PW_ENDPOINT_STREAM_CHANGE_MASK_PARAMS", "group__pw__session__manager.html#ga0389e5a5379465102059b7bc76359fc4", null ],
    [ "PW_ENDPOINT_STREAM_CHANGE_MASK_ALL", "group__pw__session__manager.html#gaad4ee430040387376438b0326e163d6d", null ],
    [ "PW_VERSION_ENDPOINT_LINK_INFO", "group__pw__session__manager.html#ga68dc5bee3ea41a4168bf87bb537848cf", null ],
    [ "PW_ENDPOINT_LINK_CHANGE_MASK_STATE", "group__pw__session__manager.html#gaf59bc21692a01d66daea31c233c5c43f", null ],
    [ "PW_ENDPOINT_LINK_CHANGE_MASK_PROPS", "group__pw__session__manager.html#gac91d84be877cdef75bab8264a2944a09", null ],
    [ "PW_ENDPOINT_LINK_CHANGE_MASK_PARAMS", "group__pw__session__manager.html#ga6f364933a37b2abbb19f0a3fcc19b64f", null ],
    [ "PW_ENDPOINT_LINK_CHANGE_MASK_ALL", "group__pw__session__manager.html#gaa5330ba264cb1a5af498d1a4b33d85ae", null ],
    [ "PW_KEY_SESSION_ID", "group__pw__session__manager.html#gab2aa7fe3e4c589dcf0e448bff2addf4e", null ],
    [ "PW_KEY_ENDPOINT_ID", "group__pw__session__manager.html#ga3a177f6b1893ad6969720adcf7683868", null ],
    [ "PW_KEY_ENDPOINT_NAME", "group__pw__session__manager.html#gad2a67bd4807e4b191b12eba4d8c9ffcd", null ],
    [ "PW_KEY_ENDPOINT_MONITOR", "group__pw__session__manager.html#ga688c705fcfd1e1f2299c46bf9792d33b", null ],
    [ "PW_KEY_ENDPOINT_CLIENT_ID", "group__pw__session__manager.html#gaf85e4d77dc57422885dd57b291b6ee9d", null ],
    [ "PW_KEY_ENDPOINT_ICON_NAME", "group__pw__session__manager.html#gab87d0172d9534c14ff37a25a14deefd9", null ],
    [ "PW_KEY_ENDPOINT_AUTOCONNECT", "group__pw__session__manager.html#ga39a3486c87f2ceae5fc7f1ccb3be65b8", null ],
    [ "PW_KEY_ENDPOINT_TARGET", "group__pw__session__manager.html#gaf5902944eccfca05247a6c6e1bc990ef", null ],
    [ "PW_KEY_ENDPOINT_STREAM_ID", "group__pw__session__manager.html#ga19f24c2c9fefe01f859c18ec29c2de8e", null ],
    [ "PW_KEY_ENDPOINT_STREAM_NAME", "group__pw__session__manager.html#ga9c5fa0d0f2d2f18e9107ba5dd49b15c2", null ],
    [ "PW_KEY_ENDPOINT_STREAM_DESCRIPTION", "group__pw__session__manager.html#gaf1cc17586c0f56a7171ac12e3d2368af", null ],
    [ "PW_KEY_ENDPOINT_LINK_OUTPUT_ENDPOINT", "group__pw__session__manager.html#ga8c6a1653431b3f9425a96aa0a6a72396", null ],
    [ "PW_KEY_ENDPOINT_LINK_OUTPUT_STREAM", "group__pw__session__manager.html#ga7dcaf114cea354db4a8f610ed968e2a7", null ],
    [ "PW_KEY_ENDPOINT_LINK_INPUT_ENDPOINT", "group__pw__session__manager.html#ga80cfd20d3e9ae11495ec8086be5ffcd5", null ],
    [ "PW_KEY_ENDPOINT_LINK_INPUT_STREAM", "group__pw__session__manager.html#gad49b77744a8b34ff01e9de478e2b4536", null ],
    [ "pw_endpoint_link_state", "group__pw__session__manager.html#ga441321996ff6d23a5b17ec8bfae05b89", [
      [ "PW_ENDPOINT_LINK_STATE_ERROR", "group__pw__session__manager.html#gga441321996ff6d23a5b17ec8bfae05b89aa6042f27dce349ddc5b10b234d01f8cf", null ],
      [ "PW_ENDPOINT_LINK_STATE_PREPARING", "group__pw__session__manager.html#gga441321996ff6d23a5b17ec8bfae05b89a0193ab427f8b36a32e90b2081be41729", null ],
      [ "PW_ENDPOINT_LINK_STATE_INACTIVE", "group__pw__session__manager.html#gga441321996ff6d23a5b17ec8bfae05b89a7107858f69fbdf1fb0bc7063ec60ee70", null ],
      [ "PW_ENDPOINT_LINK_STATE_ACTIVE", "group__pw__session__manager.html#gga441321996ff6d23a5b17ec8bfae05b89a3a45d0b018cc5443e8f126449524918e", null ]
    ] ],
    [ "pw_session_info_update", "group__pw__session__manager.html#ga6c91bc3f4125db883c3ca7eefc0f0a5a", null ],
    [ "pw_session_info_free", "group__pw__session__manager.html#ga60daa7b99b0160772e5b5b8d5696fe54", null ],
    [ "pw_endpoint_info_update", "group__pw__session__manager.html#gae52bcc1d1f43c3eed29cb24450743840", null ],
    [ "pw_endpoint_info_free", "group__pw__session__manager.html#ga0b0bc42cc601ef5c82090d463694b5c2", null ],
    [ "pw_endpoint_stream_info_update", "group__pw__session__manager.html#ga7dfd0401a9b75ae042034c7c26dd3c2d", null ],
    [ "pw_endpoint_stream_info_free", "group__pw__session__manager.html#gacd85c19b70e9c1e14b45fbbce00a030c", null ],
    [ "pw_endpoint_link_info_update", "group__pw__session__manager.html#ga80f90aa35fb48a71f43dba9043a2455e", null ],
    [ "pw_endpoint_link_info_free", "group__pw__session__manager.html#gacd887c30bf71dbac289fdc0b28f8f540", null ],
    [ "pw_client_endpoint_methods::update", "group__pw__session__manager.html#gaa8366fa5903ce48d728d5a4bf1eb6ff2", null ],
    [ "pw_client_endpoint_methods::stream_update", "group__pw__session__manager.html#gaf6d9b5f36fb09c37ae8e1cd3716618e5", null ],
    [ "pw_client_session_methods::update", "group__pw__session__manager.html#gab104098c9fd6fad4bbe290509aefbe20", null ],
    [ "pw_client_session_methods::link_update", "group__pw__session__manager.html#gad11c6d8d430ddbe887f200ea7b4c33d1", null ]
];